Module ffi

Module ffi 

Rust bindings for the C API declared in <AIR-SDK>/include/FlashRuntimeExtensions.h.

Structs

FREBitmapData
FREBitmapData2
FREByteArray
FRENamedFunction
See FREFunction.
FREObjectType
These values must not be changed.
FRERenderMode
FREResult
These values must not be changed.

Functions

FREAcquireBitmapData
Referenced data is valid only for duration of the call to a registered function.
FREAcquireBitmapData2
Referenced data is valid only for duration of the call to a registered function.
FREAcquireByteArray
Referenced data is valid only for duration of the call to a registered function.
FREAcquireNativeWindowHandle
Referenced handle is valid only for duration of the call to a registered function.
FRECallObjectMethod
@param methodName UTF8-encoded null-terminated name of the method being invoked.
FREDispatchStatusEventAsync
Causes a StatusEvent to be dispatched from the associated ExtensionContext object.
FREGetArrayElementAt
If an Array is sparse and an element that isn’t defined is requested, the return value will be FRE_OK but the handle value will be invalid.
FREGetArrayLength
@return FREResult::FRE_OK FREResult::FRE_INVALID_OBJECT FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_ILLEGAL_STATE FREResult::FRE_TYPE_MISMATCH FREResult::FRE_WRONG_THREAD
FREGetContextActionScriptData
@returns FREResult::FRE_OK FREResult::FRE_WRONG_THREAD FREResult::FRE_INVALID_ARGUMENT If actionScriptData is null.
FREGetContextNativeData
@returns FREResult::FRE_OK FREResult::FRE_WRONG_THREAD FREResult::FRE_INVALID_ARGUMENT If nativeData is null.
FREGetFREContextFromExtensionContext
Get the FREContext object associated with any ExtensionContext object. Note that the FREContext object may become invalid based on what happens with the other ExtensionContext, so this value should not be cached between function calls.
FREGetNativeContext3DHandle
Access the native context type for a Context3D object. The type depends on the render mode: currently this is only valid for OpenGL ES rendering and will return an EGLContext object. This object should be valid until the Context3D object is disposed, or the device/application loses the graphics context.
FREGetObjectAsBool
Ses FREGetObjectAsInt32.
FREGetObjectAsDouble
Ses FREGetObjectAsInt32.
FREGetObjectAsInt32
@returns FREResult::FRE_OK FREResult::FRE_TYPE_MISMATCH FREResult::FRE_INVALID_OBJECT FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_WRONG_THREAD
FREGetObjectAsUTF8
Retrieves a string representation of the object referred to by the given object. The referenced string is immutable and valid only for duration of the call to a registered function. If the caller wishes to keep the the string, they must keep a copy of it.
FREGetObjectAsUint32
Ses FREGetObjectAsInt32.
FREGetObjectProperty
@param propertyName UTF8-encoded name of the property being fetched.
FREGetObjectType
@returns FREResult::FRE_OK FREResult::FRE_INVALID_OBJECT FREResult::FRE_WRONG_THREAD FREResult::FRE_INVALID_ARGUMENT If objectType is null.
FREGetRenderMode
Returns the current render mode and mechanism for AIR
FREInvalidateBitmapDataRect
BitmapData must be acquired to call this. Clients must invalidate any region they modify in order to notify AIR of the changes. Only invalidated regions are redrawn.
FREMediaBufferLock
Locks a MediaBuffer bitmap and returns information about the data storage.
FREMediaBufferUnlock
Unlocks a MediaBuffer bitmap.
FRENewByteArray
Creates a new byte array using optional input information (length and optional byte)
FRENewObject
@param className UTF8-encoded name of the class being constructed.
FRENewObjectFromBool
Ses FRENewObjectFromInt32.
FRENewObjectFromDouble
Ses FRENewObjectFromInt32.
FRENewObjectFromInt32
@returns FREResult::FRE_OK FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_WRONG_THREAD
FRENewObjectFromUTF8
Creates a new String object that contains a copy of the specified string.
FRENewObjectFromUint32
Ses FRENewObjectFromInt32.
FREReleaseBitmapData
Release data that has been acquired with an earlier call to FREAcquireBitmapData or FREAcquireBitmapData2
FREReleaseByteArray
@return FREResult::FRE_OK FREResult::FRE_INVALID_OBJECT FREResult::FRE_ILLEGAL_STATE FREResult::FRE_WRONG_THREAD
FREReleaseNativeWindowHandle
@return FREResult::FRE_OK FREResult::FRE_INVALID_OBJECT FREResult::FRE_ILLEGAL_STATE FREResult::FRE_WRONG_THREAD
FRESetArrayElementAt
@return FREResult::FRE_OK FREResult::FRE_INVALID_OBJECT FREResult::FRE_ILLEGAL_STATE FREResult::FRE_TYPE_MISMATCH If an attempt to made to set a value in a Vector when the type of the value doesn’t match the Vector’s item type. FREResult::FRE_WRONG_THREAD
FRESetArrayLength
@return FREResult::FRE_OK FREResult::FRE_INVALID_OBJECT FREResult::FRE_TYPE_MISMATCH FREResult::FRE_ILLEGAL_STATE FREResult::FRE_INVALID_ARGUMENT If length is greater than 2^32. FREResult::FRE_READ_ONLY If the handle refers to a Vector of fixed size. FREResult::FRE_WRONG_THREAD FREResult::FRE_INSUFFICIENT_MEMORY
FRESetContextActionScriptData
@returns FREResult::FRE_OK FREResult::FRE_WRONG_THREAD
FRESetContextNativeData
@returns FREResult::FRE_OK FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_WRONG_THREAD
FRESetObjectProperty
@param propertyName UTF8-encoded name of the property being set.
FRESetRenderSource
Sets a MediaBuffer object as the rendering source for a DisplayObject.
FRETrace
Outputs a trace to the ActionScript debugger

Type Aliases

FREContextFinalizer
Defines the signature for the finalizer that is called each time an ExtensionContext instance is disposed.
FREContextInitializer
Defines the signature for the initializer that is called each time a new AS ExtensionContext object is created.
FREFinalizer
Called iff the extension is unloaded from the process. Extensions are not guaranteed to be unloaded; the runtime process may exit without doing so.
FREFunction
Defines the signature for native calls that can be invoked via an instance of the AS ExtensionContext class.
FREInitializer
The initialization function provided by each extension must conform to the following signature.