pub unsafe extern "C" fn FRECallObjectMethod(
object: FREObject,
methodName: FREStr,
argc: uint32_t,
argv: *mut FREObject,
result: *mut FREObject,
thrownException: *mut FREObject,
) -> FREResultExpand description
@param methodName UTF8-encoded null-terminated name of the method being invoked.
@param thrownException A pointer to a handle that can receive the handle of any ActionScript
Error thrown during method execution. May be null if the caller does not
want to receive this handle. If not null and no error occurs, is set an
invalid handle value.
@return FREResult::FRE_OK
FREResult::FRE_TYPE_MISMATCH
FREResult::FRE_INVALID_OBJECT
FREResult::FRE_INVALID_ARGUMENT
FREResult::FRE_ACTIONSCRIPT_ERROR If an ActionScript exception results from calling this method.
In this case, thrownException will be set to the handle of the thrown value.
FREResult::FRE_NO_SUCH_NAME If the named method doesn’t exist, or if the reference is ambiguous
because the method exists in more than one namespace.
FREResult::FRE_ILLEGAL_STATE If a ByteArray or BitmapData has been acquired and not yet released.
FREResult::FRE_WRONG_THREAD