FREDispatchStatusEventAsync

Function FREDispatchStatusEventAsync 

pub unsafe extern "C" fn FREDispatchStatusEventAsync(
    ctx: FREContext,
    code: FREStr,
    level: FREStr,
) -> FREResult
Causes a StatusEvent to be dispatched from the associated ExtensionContext object.

Dispatch happens asynchronously, even if this is called during a call to a registered function.

The ActionScript portion of this extension can listen for that event and, upon receipt, query the native portion for details of the event that occurred.

This call is thread-safe and may be invoked from any thread. The string values are copied before the call returns.

@return FREResult::FRE_OK In all circumstances, as the referenced object cannot necessarily be checked for validity on the invoking thread. However, no event will be dispatched if the object is invalid or not an EventDispatcher. FREResult::FRE_INVALID_ARGUMENT If code or level is NULL