FREGetArrayElementAt

Function FREGetArrayElementAt 

pub unsafe extern "C" fn FREGetArrayElementAt(
    arrayOrVector: FREObject,
    index: uint32_t,
    value: *mut FREObject,
) -> FREResult
If an Array is sparse and an element that isn’t defined is requested, the return value will be FRE_OK but the handle value will be invalid.

@return FREResult::FRE_OK FREResult::FRE_ILLEGAL_STATE FREResult::FRE_INVALID_ARGUMENT If the handle refers to a vector and the index is greater than the size of the array. FREResult::FRE_INVALID_OBJECT FREResult::FRE_TYPE_MISMATCH FREResult::FRE_WRONG_THREAD