FREGetObjectAsUTF8

Function FREGetObjectAsUTF8 

pub unsafe extern "C" fn FREGetObjectAsUTF8(
    object: FREObject,
    length: *mut uint32_t,
    value: *mut FREStr,
) -> FREResult
Retrieves a string representation of the object referred to by the given object. The referenced string is immutable and valid only for duration of the call to a registered function. If the caller wishes to keep the the string, they must keep a copy of it.

@param object The string to be retrieved.

@param length The size, in bytes, of the string. Includes the null terminator. (AIR-SDK-51.1.3.1) DOES NOT INCLUDE A NUL-TERMINATOR IN PRACTICE.

@param value A pointer to a possibly temporary copy of the string.

@return FREResult::FRE_OK FREResult::FRE_TYPE_MISMATCH FREResult::FRE_INVALID_OBJECT FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_WRONG_THREAD