FREGetObjectProperty

Function FREGetObjectProperty 

pub unsafe extern "C" fn FREGetObjectProperty(
    object: FREObject,
    propertyName: FREStr,
    propertyValue: *mut FREObject,
    thrownException: *mut FREObject,
) -> FREResult
@param propertyName UTF8-encoded name of the property being fetched.

@param thrownException A pointer to a handle that can receive the handle of any ActionScript Error thrown during getting the property. May be null if the caller does not want to receive this handle. If not null and no error occurs, is set an invalid handle value.

@return FREResult::FRE_OK FREResult::FRE_TYPE_MISMATCH FREResult::FRE_INVALID_OBJECT FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_ACTIONSCRIPT_ERROR If an ActionScript exception results from getting this property. In this case, thrownException will be set to the handle of the thrown value. FREResult::FRE_NO_SUCH_NAME If the named property doesn’t exist, or if the reference is ambiguous because the property exists in more than one namespace. FREResult::FRE_ILLEGAL_STATE If a ByteArray or BitmapData has been acquired and not yet released. FREResult::FRE_WRONG_THREAD