FREGetRenderMode

Function FREGetRenderMode 

pub unsafe extern "C" fn FREGetRenderMode(
    ctx: FREContext,
    stage: FREObject,
    pRenderMode: *mut uint8_t,
) -> FREResult
Returns the current render mode and mechanism for AIR

@param stage The AS3 Stage object for which to return the render mode. If this parameter is passed as NULL, the function will use the main/initial stage.

@param pRenderMode A pointer to a byte that will be populated with one of the render modes from the FRERenderMode enumeration.

@returns FREResult::FRE_OK FREResult::FRE_INVALID_ARGUMENT if pRenderMode is null FREResult::FRE_INVALID_OBJECT if stage is non-null but not a Stage object FREResult::FRE_WRONG_THREAD