FREMediaBufferUnlock

Function FREMediaBufferUnlock 

pub unsafe extern "C" fn FREMediaBufferUnlock(
    ctx: FREContext,
    mediaBuffer: FREObject,
    bUpdate: uint32_t,
) -> FREResult
Unlocks a MediaBuffer bitmap.

Currently the bUpdate parameter is ignored: changes to the data provided by the FREMediaBufferLock function will always have an impact on the rendered bitmap. This parameter is provided to allow for future flexibility.

@param ctx The FREContext for the native extension instance. @param mediaBuffer The AS3 MediaBuffer object for which the image data is released. @param bUpdate Whether to use the updated data for rendering. Note that this parameter may not have any effect.

@returns FREResult::FRE_OK FREResult::FRE_INVALID_ARGUMENT if the ctx or mediaBuffer parameter is null FREResult::FRE_INVALID_OBJECT if the MediaBuffer objects has an incorrect type FREResult::FRE_WRONG_THREAD if called from the wrong thread; at some point this function will be updated to allow multi-thread calling