FRENewObject

Function FRENewObject 

pub unsafe extern "C" fn FRENewObject(
    className: FREStr,
    argc: uint32_t,
    argv: *mut FREObject,
    object: *mut FREObject,
    thrownException: *mut FREObject,
) -> FREResult
@param className UTF8-encoded name of the class being constructed.

@param thrownException A pointer to a handle that can receive the handle of any ActionScript Error thrown during execution. May be null if the caller does not want to receive this handle. If not null and no error occurs, is set an invalid handle value.

@return FREResult::FRE_OK FREResult::FRE_TYPE_MISMATCH FREResult::FRE_INVALID_OBJECT FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_ACTIONSCRIPT_ERROR If an ActionScript exception results from calling this method. In this case, thrownException will be set to the handle of the thrown value. FREResult::FRE_ILLEGAL_STATE If a ByteArray or BitmapData has been acquired and not yet released. FREResult::FRE_NO_SUCH_NAME FREResult::FRE_WRONG_THREAD