FRENewObjectFromUTF8

Function FRENewObjectFromUTF8 

pub unsafe extern "C" fn FRENewObjectFromUTF8(
    length: uint32_t,
    value: FREStr,
    object: *mut FREObject,
) -> FREResult
Creates a new String object that contains a copy of the specified string.

@param length The length, in bytes, of the original string. Must include the null terminator.

@param value A pointer to the original string.

@param object Receives a reference to the new string object.

@return FREResult::FRE_OK FREResult::FRE_INVALID_ARGUMENT FREResult::FRE_WRONG_THREAD