FRESetArrayElementAt

Function FRESetArrayElementAt 

pub unsafe extern "C" fn FRESetArrayElementAt(
    arrayOrVector: FREObject,
    index: uint32_t,
    value: FREObject,
) -> FREResult
@return FREResult::FRE_OK FREResult::FRE_INVALID_OBJECT FREResult::FRE_ILLEGAL_STATE FREResult::FRE_TYPE_MISMATCH If an attempt to made to set a value in a Vector when the type of the value doesn’t match the Vector’s item type. FREResult::FRE_WRONG_THREAD