FRESetRenderSource

Function FRESetRenderSource 

pub unsafe extern "C" fn FRESetRenderSource(
    ctx: FREContext,
    source: FREObject,
    target: FREObject,
) -> FREResult
Sets a MediaBuffer object as the rendering source for a DisplayObject.

@param source The AS3 MediaBuffer object that will be used to render into the display object.

@param target The AS3 DisplayObject object that will render the contents from the MediaBuffer.

@returns FREResult::FRE_OK FREResult::FRE_INVALID_ARGUMENT if either element is null FREResult::FRE_INVALID_OBJECT if the objects are incorrect types FREResult::FRE_WRONG_THREAD