FREFunction

Type Alias FREFunction 

pub type FREFunction = unsafe extern "C" fn(ctx: FREContext, functionData: FREData, argc: uint32_t, argv: *const FREObject) -> FREObject;
Defines the signature for native calls that can be invoked via an instance of the AS ExtensionContext class.

@return The return value corresponds to the return value from the AS ExtensionContext class call() method. It defaults to FREResult::FRE_INVALID_OBJECT, which is reported as null in AS.