pub unsafe extern "C" fn FREAcquireByteArray(
object: FREObject,
byteArrayToSet: *mut FREByteArray,
) -> FREResultExpand description
Referenced data is valid only for duration of the call to a registered function.
pub unsafe extern "C" fn FREAcquireByteArray(
object: FREObject,
byteArrayToSet: *mut FREByteArray,
) -> FREResultReferenced data is valid only for duration of the call to a registered function.