pub unsafe extern "C" fn FREAcquireNativeWindowHandle(
nativeWindow: FREObject,
handle: *mut FRENativeWindow,
) -> FREResultExpand description
Referenced handle is valid only for duration of the call to a registered function.
pub unsafe extern "C" fn FREAcquireNativeWindowHandle(
nativeWindow: FREObject,
handle: *mut FRENativeWindow,
) -> FREResultReferenced handle is valid only for duration of the call to a registered function.