pub unsafe extern "C" fn FREDispatchStatusEventAsync(
ctx: FREContext,
code: FREStr,
level: FREStr,
) -> FREResultExpand description
Causes a StatusEvent to be dispatched from the associated ExtensionContext object.
Dispatch happens asynchronously, even if this is called during a call to a registered function.
The AS3 portion of this extension can listen for that event and, upon receipt, query the native portion for details of the event that occurred.
This call is thread-safe and may be invoked from any thread. The string values are copied before the call returns.
Returns
FREResult::FRE_OKIn all circumstances, as the referenced object cannot necessarily be checked for validity on the invoking thread. However, no event will be dispatched if the object is invalid or not anEventDispatcher.FREResult::FRE_INVALID_ARGUMENTIfcodeorlevelis null.