FREGetArrayElementAt

Function FREGetArrayElementAt 

pub unsafe extern "C" fn FREGetArrayElementAt(
    arrayOrVector: FREObject,
    index: u32,
    value: *mut FREObject,
) -> FREResult
If an Array is sparse and an element that isn’t defined is requested, the return value will be FREResult::FRE_OK but the handle value will be invalid.

Returns