FREGetObjectProperty

Function FREGetObjectProperty 

pub unsafe extern "C" fn FREGetObjectProperty(
    object: FREObject,
    propertyName: FREStr,
    propertyValue: *mut FREObject,
    thrownException: *mut FREObject,
) -> FREResult
Parameters

  • propertyName: UTF-8 encoded name of the property being fetched.
  • thrownException: A pointer to a handle that can receive the handle of any AS3 Error thrown during getting the property. May be null if the caller does not want to receive this handle. If not null and no error occurs, it is set to an invalid handle value.

Returns