pub unsafe extern "C" fn FREGetRenderMode(
ctx: FREContext,
stage: FREObject,
pRenderMode: *mut FRERenderMode,
) -> FREResultExpand description
Returns the current render mode and mechanism for AIR
Parameters
stage: The AS3Stageobject for which to return the render mode. If this parameter is passed as null, the function will use the main/initial stage.pRenderMode: A pointer to a byte that will be populated with one of the render modes from theFRERenderModeenumeration.
Returns
FREResult::FRE_OKFREResult::FRE_INVALID_ARGUMENTIfpRenderModeis null.FREResult::FRE_INVALID_OBJECTIfstageis non-null but not aStageobject.FREResult::FRE_WRONG_THREAD