FREMediaBufferUnlock

Function FREMediaBufferUnlock 

pub unsafe extern "C" fn FREMediaBufferUnlock(
    ctx: FREContext,
    mediaBuffer: FREObject,
    bUpdate: u32,
) -> FREResult
Unlocks a MediaBuffer bitmap.

Currently the bUpdate parameter is ignored: changes to the data provided by the FREMediaBufferLock function will always have an impact on the rendered bitmap. This parameter is provided to allow for future flexibility.

Parameters

  • ctx: The FREContext for the native extension instance.
  • mediaBuffer: The AS3 MediaBuffer object for which the image data is released.
  • bUpdate: Whether to use the updated data for rendering. Note that this parameter may not have any effect.

Returns