FRESetObjectProperty

Function FRESetObjectProperty 

pub unsafe extern "C" fn FRESetObjectProperty(
    object: FREObject,
    propertyName: FREStr,
    propertyValue: FREObject,
    thrownException: *mut FREObject,
) -> FREResult
Parameters

  • propertyName: UTF-8 encoded name of the property being set.
  • thrownException: A pointer to a handle that can receive the handle of any AS3 Error thrown during method execution. May be null if the caller does not want to receive this handle. If not null and no error occurs, it is set to an invalid handle value.

Returns