pub unsafe extern "C" fn FRESetRenderSource(
ctx: FREContext,
source: FREObject,
target: FREObject,
) -> FREResultExpand description
Sets a MediaBuffer object as the rendering source for a DisplayObject.
Parameters
source: The AS3MediaBufferobject that will be used to render into the display object.target: The AS3DisplayObjectobject that will render the contents from theMediaBuffer.
Returns
FREResult::FRE_OKFREResult::FRE_INVALID_ARGUMENTIf either argument is null.FREResult::FRE_INVALID_OBJECTIf the objects are incorrect types.FREResult::FRE_WRONG_THREAD