pub type FREContextFinalizer = unsafe extern "C" fn(ctx: FREContext);Expand description
Defines the signature for the finalizer that is called each time
an ExtensionContext instance is disposed.
pub type FREContextFinalizer = unsafe extern "C" fn(ctx: FREContext);Defines the signature for the finalizer that is called each time
an ExtensionContext instance is disposed.