pub type FREFinalizer = unsafe extern "C" fn(extData: FREData);Expand description
Called iff the extension is unloaded from the process. Extensions are not guaranteed to be unloaded; the runtime process may exit without doing so.
This function is optional and may be omitted by not declaring
<finalizer>...</finalizer> in the extension configuration file.