pub type FREInitializer = unsafe extern "C" fn(extDataToSet: *mut FREData, ctxInitializerToSet: *mut FREContextInitializer, ctxFinalizerToSet: *mut Option<FREContextFinalizer>);Expand description
The initialization function provided by each extension must conform to the following signature.
Parameters
extDataToSet: Provided for the extension to store per-extension instance data. For example, if the extension creates globals per-instance, it can store a pointer to them here.ctxInitializerToSet: Must be set to a function pointer of typeFREContextInitializer. Will be invoked whenever the AS3 code creates a new context for this extension.ctxFinalizerToSet: Must be set to a function pointer of typeFREContextFinalizer, or left asNone.