Rust bindings for the C API declared in <AIR-SDK>/include/FlashRuntimeExtensions.h.
Structs
- FREBitmap
Data - FREBitmap
Data2 - FREByte
Array - FRENamed
Function - See
FREFunction. - FREObject
Type - These values must not be changed.
- FRERender
Mode - FREResult
- These values must not be changed.
Functions
- FREAcquire
Bitmap ⚠Data - Referenced data is valid only for duration of the call to a registered function.
- FREAcquire
Bitmap ⚠Data2 - Referenced data is valid only for duration of the call to a registered function.
- FREAcquire
Byte ⚠Array - Referenced data is valid only for duration of the call to a registered function.
- FREAcquire
Native ⚠Window Handle - Referenced handle is valid only for duration of the call to a registered function.
- FRECall
Object ⚠Method - @param
methodNameUTF8-encoded null-terminated name of the method being invoked. - FREDispatch
Status ⚠Event Async - Causes a
StatusEventto be dispatched from the associatedExtensionContextobject. - FREGet
Array ⚠Element At - If an
Arrayis sparse and an element that isn’t defined is requested, the return value will be FRE_OK but the handle value will be invalid. - FREGet
Array ⚠Length - @return
FREResult::FRE_OKFREResult::FRE_INVALID_OBJECTFREResult::FRE_INVALID_ARGUMENTFREResult::FRE_ILLEGAL_STATEFREResult::FRE_TYPE_MISMATCHFREResult::FRE_WRONG_THREAD - FREGet
Context ⚠Action Script Data - @returns
FREResult::FRE_OKFREResult::FRE_WRONG_THREADFREResult::FRE_INVALID_ARGUMENTIfactionScriptDatais null. - FREGet
Context ⚠Native Data - @returns
FREResult::FRE_OKFREResult::FRE_WRONG_THREADFREResult::FRE_INVALID_ARGUMENTIfnativeDatais null. - FREGetFRE
Context ⚠From Extension Context - Get the
FREContextobject associated with anyExtensionContextobject. Note that theFREContextobject may become invalid based on what happens with the otherExtensionContext, so this value should not be cached between function calls. - FREGet
Native ⚠Context3D Handle - Access the native context type for a
Context3Dobject. The type depends on the render mode: currently this is only valid for OpenGL ES rendering and will return anEGLContextobject. This object should be valid until theContext3Dobject is disposed, or the device/application loses the graphics context. - FREGet
Object ⚠AsBool - Ses
FREGetObjectAsInt32. - FREGet
Object ⚠AsDouble - Ses
FREGetObjectAsInt32. - FREGet
Object ⚠AsInt32 - @returns
FREResult::FRE_OKFREResult::FRE_TYPE_MISMATCHFREResult::FRE_INVALID_OBJECTFREResult::FRE_INVALID_ARGUMENTFREResult::FRE_WRONG_THREAD - FREGet
Object ⚠AsUT F8 - Retrieves a string representation of the object referred to by the given object. The referenced string is immutable and valid only for duration of the call to a registered function. If the caller wishes to keep the the string, they must keep a copy of it.
- FREGet
Object ⚠AsUint32 - Ses
FREGetObjectAsInt32. - FREGet
Object ⚠Property - @param
propertyNameUTF8-encoded name of the property being fetched. - FREGet
Object ⚠Type - @returns
FREResult::FRE_OKFREResult::FRE_INVALID_OBJECTFREResult::FRE_WRONG_THREADFREResult::FRE_INVALID_ARGUMENTIfobjectTypeis null. - FREGet
Render ⚠Mode - Returns the current render mode and mechanism for AIR
- FREInvalidate
Bitmap ⚠Data Rect BitmapDatamust be acquired to call this. Clients must invalidate any region they modify in order to notify AIR of the changes. Only invalidated regions are redrawn.- FREMedia
Buffer ⚠Lock - Locks a
MediaBufferbitmap and returns information about the data storage. - FREMedia
Buffer ⚠Unlock - Unlocks a
MediaBufferbitmap. - FRENew
Byte ⚠Array - Creates a new byte array using optional input information (
lengthand optionalbyte) - FRENew
Object ⚠ - @param
classNameUTF8-encoded name of the class being constructed. - FRENew
Object ⚠From Bool - Ses
FRENewObjectFromInt32. - FRENew
Object ⚠From Double - Ses
FRENewObjectFromInt32. - FRENew
Object ⚠From Int32 - @returns
FREResult::FRE_OKFREResult::FRE_INVALID_ARGUMENTFREResult::FRE_WRONG_THREAD - FRENew
Object ⚠FromUT F8 - Creates a new
Stringobject that contains a copy of the specified string. - FRENew
Object ⚠From Uint32 - Ses
FRENewObjectFromInt32. - FRERelease
Bitmap ⚠Data - Release data that has been acquired with an earlier call to
FREAcquireBitmapDataorFREAcquireBitmapData2 - FRERelease
Byte ⚠Array - @return
FREResult::FRE_OKFREResult::FRE_INVALID_OBJECTFREResult::FRE_ILLEGAL_STATEFREResult::FRE_WRONG_THREAD - FRERelease
Native ⚠Window Handle - @return
FREResult::FRE_OKFREResult::FRE_INVALID_OBJECTFREResult::FRE_ILLEGAL_STATEFREResult::FRE_WRONG_THREAD - FRESet
Array ⚠Element At - @return
FREResult::FRE_OKFREResult::FRE_INVALID_OBJECTFREResult::FRE_ILLEGAL_STATEFREResult::FRE_TYPE_MISMATCHIf an attempt to made to set a value in aVectorwhen the type of the value doesn’t match theVector’s item type.FREResult::FRE_WRONG_THREAD - FRESet
Array ⚠Length - @return
FREResult::FRE_OKFREResult::FRE_INVALID_OBJECTFREResult::FRE_TYPE_MISMATCHFREResult::FRE_ILLEGAL_STATEFREResult::FRE_INVALID_ARGUMENTIflengthis greater than 2^32.FREResult::FRE_READ_ONLYIf the handle refers to aVectorof fixed size.FREResult::FRE_WRONG_THREADFREResult::FRE_INSUFFICIENT_MEMORY - FRESet
Context ⚠Action Script Data - @returns
FREResult::FRE_OKFREResult::FRE_WRONG_THREAD - FRESet
Context ⚠Native Data - @returns
FREResult::FRE_OKFREResult::FRE_INVALID_ARGUMENTFREResult::FRE_WRONG_THREAD - FRESet
Object ⚠Property - @param
propertyNameUTF8-encoded name of the property being set. - FRESet
Render ⚠Source - Sets a
MediaBufferobject as the rendering source for aDisplayObject. - FRETrace⚠
- Outputs a trace to the ActionScript debugger
Type Aliases
- FREContext
Finalizer - Defines the signature for the finalizer that is called each time
an
ExtensionContextinstance is disposed. - FREContext
Initializer - Defines the signature for the initializer that is called each time
a new AS
ExtensionContextobject is created. - FREFinalizer
- Called iff the extension is unloaded from the process. Extensions are not guaranteed to be unloaded; the runtime process may exit without doing so.
- FREFunction
- Defines the signature for native calls that can be invoked via an
instance of the AS
ExtensionContextclass. - FREInitializer
- The initialization function provided by each extension must conform to the following signature.