pub unsafe extern "C" fn FREGetFREContextFromExtensionContext(
objExtensionContext: FREObject,
pContext: *mut FREContext,
) -> FREResultExpand description
Get the FREContext object associated with any ExtensionContext object. Note that
the FREContext object may become invalid based on what happens with the other ExtensionContext,
so this value should not be cached between function calls.
@param objExtensionContext The ExtensionContext (ActionScript object) for which the FREContext handle is required.
@param pContext The FREContext (C handle) associated with the given ExtensionContext.
@return FREResult::FRE_OK
FREResult::FRE_TYPE_MISMATCH
FREResult::FRE_INVALID_OBJECT
FREResult::FRE_INVALID_ARGUMENT
FREResult::FRE_WRONG_THREAD
FREResult::FRE_ILLEGAL_STATE