pub type FREInitializer = unsafe extern "C" fn(extDataToSet: *mut FREData, ctxInitializerToSet: *mut FREContextInitializer, ctxFinalizerToSet: *mut FREContextFinalizer);Expand description
The initialization function provided by each extension must conform to the following signature.
@param extDataToSet Provided for the extension to store per-extension instance data.
For example, if the extension creates
globals per-instance, it can store a pointer to them here.
@param ctxInitializerToSet Must be set to a pointer to a function
of type FREContextInitializer. Will be invoked whenever
the ActionScript code creates a new context for this extension.
@param ctxFinalizerToSet Must be set to a pointer to a function
of type FREContextFinalizer.