pub unsafe extern "C" fn FREGetArrayElementAt(
arrayOrVector: FREObject,
index: u32,
value: *mut FREObject,
) -> FREResultExpand description
If an Array is sparse and an element that isn’t defined is requested,
the return value will be FREResult::FRE_OK but the handle value will be invalid.
Returns
FREResult::FRE_OKFREResult::FRE_ILLEGAL_STATEFREResult::FRE_INVALID_ARGUMENTIf the handle refers to a vector and the index is greater than the size of the array.FREResult::FRE_INVALID_OBJECTFREResult::FRE_TYPE_MISMATCHFREResult::FRE_WRONG_THREAD