propertyName: UTF-8 encoded name of the property being fetched.
thrownException: A pointer to a handle that can receive the handle of any AS3 Error thrown during getting the property.
May be null if the caller does not want to receive this handle.
If not null and no error occurs, it is set to an invalid handle value.
FREResult::FRE_ACTIONSCRIPT_ERROR If an AS3 exception results from getting this property.
In this case, thrownException will be set to the handle of the thrown value.
FREResult::FRE_NO_SUCH_NAME If the named property doesn’t exist,
or if the reference is ambiguous because the property exists in more than one namespace.