pub unsafe extern "C" fn FREMediaBufferUnlock(
ctx: FREContext,
mediaBuffer: FREObject,
bUpdate: u32,
) -> FREResultExpand description
Unlocks a MediaBuffer bitmap.
Currently the bUpdate parameter is ignored: changes to the data provided by the FREMediaBufferLock function will
always have an impact on the rendered bitmap. This parameter is provided to allow for future flexibility.
Parameters
ctx: TheFREContextfor the native extension instance.mediaBuffer: The AS3MediaBufferobject for which the image data is released.bUpdate: Whether to use the updated data for rendering. Note that this parameter may not have any effect.
Returns
FREResult::FRE_OKFREResult::FRE_INVALID_ARGUMENTIf thectxormediaBufferparameter is null.FREResult::FRE_INVALID_OBJECTIf theMediaBufferobject has an incorrect type.FREResult::FRE_WRONG_THREADIf called from the wrong thread; at some point this function will be updated to allow multi-thread calling.