Type aliases for C API–compatible pointer types and semantic markers used by the extension API.
Type Aliases
- FREBoolean
- 32-bit integer representation of an ActionScript
Boolean. - FREBytes
- Pointer to a byte buffer.
- FREContext
- Handle to an extension context managed by the runtime.
- FREData
- Handle to user-defined data owned and managed by extensions.
- FREHandle
- Opaque pointer to an unspecified data type.
- FRENative
Window - Handle to a native window; the underlying type is platform-specific.
- FREObject
- Handle to an ActionScript
Object. - FREStr
- Borrowed pointer to UTF-8 string.