pub type FREFunction = unsafe extern "C" fn(ctx: FREContext, functionData: FREData, argc: u32, argv: *const FREObject) -> FREObject;Expand description
Defines the signature for native calls that can be invoked via an instance
of the AS3 ExtensionContext class.
The return value corresponds to the return value from the AS3 ExtensionContext.call method.
Returning an invalid handle value is observed as null in AS3.